import { FieldBase } from './DataSourceInterfaces';
import { EncodingType, MarkType } from './Namespaces/Tableau';
/**
 * @since 1.11.0
 * Represents a collection of fields on various encodings as well as other viz specific information for a worksheet
 */
export interface VisualSpecification {
    readonly rowFields: FieldInstance[];
    readonly columnFields: FieldInstance[];
    readonly activeMarksSpecificationIndex: number;
    readonly marksSpecifications: MarksSpecification[];
}
/**
 * @since 1.11.0
 * Represents a collection of fields on various encodings for a single marks card
 */
export interface MarksSpecification {
    readonly primitiveType: MarkType;
    readonly encodings: Encoding[];
}
/**
 * @since 1.11.0
 * Represents a single field and its associated encoding on a marks card
 */
export interface Encoding {
    /**
     * @returns inbuilt encoding type or the custom encoding
     */
    readonly id: string;
    /**
     * @returns The unique representation of the encodings,
     * This allows to identify the duplicate fields that are added to encodings.
     * @since 1.13.0
     */
    readonly fieldEncodingId: string;
    /**
     * @returns type of the encoding
     */
    readonly type: EncodingType;
    /**
     * @returns Field and its properties
     */
    readonly field: FieldInstance;
}
/**
 * @since 1.11.0
 * Represents a field and its properties
 */
export interface FieldInstance extends FieldBase {
    /**
     * @returns The unique representation of the field across all data sources in the workbook. In summary data, this includes aggregation.
     * Note that the fieldId could change if you change the data source.
     * For example after replacing the data source [Clipboard_20210305T164000].[sum:Sales:qk] could become
     * [federated.12usuoq1171o1b1ebdyh60fjnev1].[sum:Sales:qk].
     */
    readonly fieldId: string;
}
//# sourceMappingURL=VisualModelInterface.d.ts.map